==> cyberdrop_dl_patched-5.7.3b0.tar.gz: cyberdrop_dl_patched-5.7.3b0/cyberdrop_dl/config_definitions/custom_types.py <==
from __future__ import annotations

from datetime import datetime, timedelta
from typing import Annotated

import humanfriendly
from pydantic import (
    AfterValidator,
    AnyUrl,
    BaseModel,
    ConfigDict,
    HttpUrl,
    Secret,
    SerializationInfo,
    StringConstraints,
    model_serializer,
    model_validator,
)
from yarl import URL


def convert_to_yarl(value: AnyUrl) -> URL:
    return URL(str(value))


HttpURL = Annotated[HttpUrl, AfterValidator(convert_to_yarl)]
NonEmptyStr = Annotated[str, StringConstraints(min_length=1, strip_whitespace=True)]
AnyURL = Annotated[AnyUrl, AfterValidator(convert_to_yarl)]
SecretAnyURL = Secret[AnyURL]
SecretHttpURL = Secret[HttpURL]


class AliasModel(BaseModel):
    model_config = ConfigDict(populate_by_name=True)


class FrozenModel(BaseModel):
    model_config = ConfigDict(frozen=True)


class AppriseURLModel(FrozenModel):
    url: SecretAnyURL
    tags: set[str]

    @model_serializer()
    def serialize(self, info: SerializationInfo):
        dump_secret = info.mode != "json"
        url = self.url.get_secret_value() if dump_secret else self.url
        tags = self.tags - set("no_logs")
        return f"{','.join(tags)}{'=' if tags else ''}{url}"

    @model_validator(mode="before")
    @staticmethod
    def parse_input(value: dict | URL | str):
        url_obj = value
        tags = None
        if isinstance(url_obj, dict):
            tags = url_obj.get("tags")
            url_obj = url_obj.get("url")
        if isinstance(value, URL):
            url_obj = str(value)
        url = AppriseURL(url_obj, validate=False)
        return {"url": url._url, "tags": tags or url.tags or set("no_logs")}


class AppriseURL:
    _validator = AppriseURLModel

    def __init__(self, url: URL | str, tags: set | None = None, *, validate: bool = True):
        self._actual_url = None
        self._url = str(url)
        if validate:
            self._validate()
        else:
            self.parse_str(url, tags)

    @property
    def tags(self) -> set[str]:
        return self._tags

    @property
    def url(self) -> URL:
        self._validate()
        return self._actual_url

    def parse_str(self, url: URL | str, tags: set | None = None):
        self._tags = tags or set("no_logs")
        self._url = str(url)
        self._actual_url = url if isinstance(url, URL) else None
        parts = self._url.split("://", 1)[0].split("=", 1)
        if len(parts) == 2 and not self._actual_url:
            self._tags = set(parts[0].split(","))
            self._url: str = url.split("=", 1)[-1]

    def _validate(self):
        if not self._actual_url:
            apprise_model = self._validator(url=self._url)
            self._actual_url = apprise_model.url

    def __repr__(self):
        return f"AppriseURL({self._url}, tags={self.tags})"

    def __str__(self):
        return f"{','.join(self.tags)}{'=' if self.tags else ''}{self.url}"


class HttpAppriseURLModel(AppriseURLModel):
    url: SecretHttpURL


class HttpAppriseURL(AppriseURL):
    _validator = HttpAppriseURLModel


class CacheDuration(BaseModel):
    duration: timedelta = timedelta(days=7)

    @staticmethod
    def parse_cache_duration(value: str) -> timedelta:
        """
        Parses a human-readable duration string (e.g., '7 days', '2 hours').
        """
        try:
            seconds = humanfriendly.parse_timespan(value)
            return timedelta(seconds=seconds)
        except humanfriendly.InvalidTimespan as e:
            raise ValueError(f"Invalid cache duration format: {value}") from e

    @model_validator(mode="before")
    @classmethod
    def validate_cache_duration(cls, values):
        if isinstance(values, dict) and isinstance(values.get("duration"), str):
            values["duration"] = cls.parse_cache_duration(values["duration"])
        elif isinstance(values, str):  # For direct string initialization
            return {"duration": cls.parse_cache_duration(values)}
        return values

    @model_serializer()
    def serialize_cache_duration(self):
        """
        Serializes the duration into a human-readable string.
        """

        if isinstance(self, timedelta):
            return humanfriendly.format_timespan(self.total_seconds(), detailed=False)
        elif isinstance(self.duration, timedelta):
            return humanfriendly.format_timespan(self.duration.total_seconds(), detailed=False)

    def __radd__(self, other):
        if isinstance(other, datetime) or isinstance(other, timedelta):
            return other + self.duration
        return NotImplemented

==> cyberdrop_dl_patched-6.1.1.dev2.tar.gz: cyberdrop_dl_patched-6.1.1.dev2/cyberdrop_dl/config_definitions/custom_types.py <==
from __future__ import annotations

from typing import Annotated

from pydantic import (
    AfterValidator,
    AnyUrl,
    BaseModel,
    ConfigDict,
    HttpUrl,
    Secret,
    SerializationInfo,
    StringConstraints,
    model_serializer,
    model_validator,
)
from yarl import URL


def convert_to_yarl(value: AnyUrl) -> URL:
    return URL(str(value))


HttpURL = Annotated[HttpUrl, AfterValidator(convert_to_yarl)]
NonEmptyStr = Annotated[str, StringConstraints(min_length=1, strip_whitespace=True)]
AnyURL = Annotated[AnyUrl, AfterValidator(convert_to_yarl)]
SecretAnyURL = Secret[AnyURL]
SecretHttpURL = Secret[HttpURL]


class AliasModel(BaseModel):
    model_config = ConfigDict(populate_by_name=True)


class FrozenModel(BaseModel):
    model_config = ConfigDict(frozen=True)


class AppriseURLModel(FrozenModel):
    url: Secret[AnyUrl]
    tags: set[str]

    @model_serializer()
    def serialize(self, info: SerializationInfo):
        dump_secret = info.mode != "json"
        url = self.url.get_secret_value() if dump_secret else self.url
        tags = self.tags - set("no_logs")
        tags = sorted(tags)
        return f"{','.join(tags)}{'=' if tags else ''}{url}"

    @model_validator(mode="before")
    @staticmethod
    def parse_input(value: dict | URL | str):
        url = value
        tags = set()
        if isinstance(value, dict):
            tags = value.get("tags") or tags
            url = value.get("url", "")

        if isinstance(url, URL):
            url = str(url)
        parts = url.split("://", 1)[0].split("=", 1)
        if len(parts) == 2:
            tags = set(parts[0].split(","))
            url: str = url.split("=", 1)[-1]

        return {"url": url, "tags": tags}


class HttpAppriseURL(AppriseURLModel):
    url: Secret[HttpURL]
